
declare module KiwiCore.Models {
	interface Adjustment extends KiwiCore.Models.BaseModel {
		AdjustmentId: number;
		Description: string;
		OrderId: number;
		TotalAdjustmentAmount: number;
		TotalAdjustmentAmountExt: string;
		TotalActualAmount: number;
		Customer: KiwiCore.Models.Customer;
		Notes: KiwiCore.Models.Note[];
		AdjustmentType: KiwiCore.Enums.AdjustmentType;
		AdjustmentTypeName: string;
		Status: KiwiCore.Enums.AdjustmentStatus;
		StatusName: string;
		PoNumber: string;
		IsCredit: boolean;
		AdjustmentDetails: KiwiCore.Models.AdjustmentDetail[];
		Attachments: KiwiCore.Models.Attachment[];
		Author: KiwiCore.Models.AdvUser;
		Site: KiwiCore.Models.Site;
		AdHocApprovers: string[];
		UserDelegators: KiwiCore.Models.AdvUser[];
		AttachmentsReadOnly: boolean;
		CreatePeriod: KiwiCore.Models.FiscalPeriod;
		BatchPeriod: KiwiCore.Models.FiscalPeriod;
		SetupIssues: KiwiCore.Models.SetupIssue[];
		Acl: KiwiCore.Models.AdjustmentAcl;
		StatusReadOnly: boolean;
		Value: number;
		Text: string;
	}
	interface BaseModel {
		CreatedOn: Date;
		CreatedOnFriendly: string;
		UpdatedOn: Date;
		UpdatedOnFriendly: string;
		CreatedBy: KiwiCore.Models.User;
		UpdatedBy: KiwiCore.Models.User;
		IsDirty: boolean;
	}
	interface User extends KiwiCore.Models.BaseModel {
		UserId: number;
		UserSid: string;
		FirstName: string;
		LastName: string;
		NetName: string;
		Email: string;
		EmailOverride: string;
		IsActive: boolean;
		IsSysAdmin: boolean;
		Domain: string;
		Sites: KiwiCore.Models.UserSite[];
		LastUsedSite: KiwiCore.Models.UserSite;
		LastLoginOn: Date;
		LastLoginOnFriendly: string;
		AdvUser: KiwiCore.Models.AdvUser;
		Value: number;
		Text: string;
		FullName: string;
	}
	interface UserSite extends KiwiCore.Models.BaseModel {
		UserSiteId: number;
		Site: KiwiCore.Models.Site;
		IsActive: boolean;
		User: KiwiCore.Models.User;
		Roles: KiwiCore.Models.Role[];
		OverDollarAmount: number;
		EmailType: KiwiCore.Enums.EmailType;
		IsDailyEmail: boolean;
		Supervisor: KiwiCore.Models.Supervisor;
		DelegateUserSiteId: number;
		DelegateName: string;
		IsDelegateActive: boolean;
		DelegateEndDate: Date;
		DelegateUserId: number;
		DelegateFor: KiwiCore.Models.Delegator[];
		DelegateForFriendly: string;
		DelegateForAll: KiwiCore.Models.Delegator[];
		Value: number;
		Text: string;
	}
	interface Site extends KiwiCore.Models.BaseModel {
		SiteId: number;
		SiteName: string;
		EnterpriseCode: string;
		SystemType: KiwiCore.Enums.SystemType;
		SystemTypeName: string;
		IsLocked: boolean;
		Connections: KiwiCore.Models.SiteAppEnv[];
		GlCompanyCode: string;
		IsActive: boolean;
		SiteConfigs: System.Collections.Generic.KeyValuePair<KiwiCore.Enums.SiteConfigType, string>[];
		Value: number;
		Text: string;
	}
	interface SiteAppEnv extends KiwiCore.Models.BaseModel {
		Site: KiwiCore.Models.Site;
		Environment: KiwiCore.Enums.AppEnvironment;
		ConnectionString: string;
		DatabaseName: string;
		IsActive: boolean;
		SiteConnectionId: number;
		Value: number;
		Text: string;
	}
	interface Role extends KiwiCore.Models.BaseModel {
		RoleId: number;
		RoleName: string;
		IsActive: boolean;
		IsUserEditable: boolean;
		IsDelegate: boolean;
		Value: number;
		Text: string;
	}
	interface Supervisor extends KiwiCore.Models.User {
		Subordinates: KiwiCore.Models.UserSite[];
	}
	interface Delegator {
		UserId: number;
		UserSiteId: number;
		SiteId: number;
		FirstName: string;
		LastName: string;
		NetName: string;
		Value: number;
		Text: string;
	}
	interface AdvUser extends KiwiCore.Models.BaseModel {
		UserId: string;
		UserName: string;
		NetName: string;
		SalesPersonId: string;
		Value: number;
		Text: string;
	}
	interface Customer extends KiwiCore.Models.BaseModel {
		CustomerId: number;
		CustomerNbr: string;
		CustomerName: string;
		CustomerTypeId: number;
		Value: number;
		Text: string;
	}
	interface Note extends KiwiCore.Models.BaseModel {
		NoteId: number;
		NoteContent: string;
		Value: number;
		Text: string;
	}
	interface AdjustmentDetail extends KiwiCore.Models.BaseModel {
		Adjustment: KiwiCore.Models.Adjustment;
		AdjustmentDetailId: number;
		Publication: KiwiCore.Models.Publication;
		AdjCode: KiwiCore.Models.AdjustmentCode;
		RoutingType: KiwiCore.Enums.RoutingType;
		GlAccount: KiwiCore.Models.GlAccount;
		AdId: number;
		AdjustmentAmount: number;
		AdjustmentAmountMax: number;
		ActualAmount: number;
		SalesPerson: KiwiCore.Models.Salesperson;
		SectionName: KiwiCore.Models.SectionName;
		Status: KiwiCore.Enums.AdjustmentStatus;
		AdjustmentReviews: KiwiCore.Models.AdjustmentReview[];
		Notes: string;
		CategoryName: KiwiCore.Models.CategoryName;
		SectionType: KiwiCore.Models.SectionType;
		AdType: KiwiCore.Models.AdType;
		AdPromotion: KiwiCore.Models.Promotion;
		DefaultGlAccount: KiwiCore.Models.GlAccount;
		Service: KiwiCore.Models.Service;
		CheckNo: string;
		Value: number;
		Text: string;
	}
	interface Publication extends KiwiCore.Models.BaseModel {
		PublicationId: string;
		PublicationName: string;
		SystemType: KiwiCore.Enums.SystemType;
		Sections: KiwiCore.Models.Section[];
		Value: number;
		Text: string;
	}
	interface Section extends KiwiCore.Models.BaseModel {
		SectionId: string;
		SectionNameString: string;
		Categories: KiwiCore.Models.Category[];
		SystemType: KiwiCore.Enums.SystemType;
		SectionType: KiwiCore.Models.SectionType;
		SectionName: KiwiCore.Models.SectionName;
		Publication: KiwiCore.Models.Publication;
		Value: number;
		Text: string;
	}
	interface Category extends KiwiCore.Models.BaseModel {
		CategoryId: string;
		CategoryName: string;
		SectionType: KiwiCore.Models.SectionType;
		AdTypes: KiwiCore.Models.AdType[];
		Sections: KiwiCore.Models.Section[];
		Value: number;
		Text: string;
	}
	interface SectionType extends KiwiCore.Models.BaseModel {
		SectionTypeId: string;
		SectionTypeName: string;
		Value: number;
		Text: string;
	}
	interface AdType extends KiwiCore.Models.BaseModel {
		AdTypeId: string;
		AdTypeName: string;
		SectionTypes: KiwiCore.Models.SectionType[];
		Value: number;
		Text: string;
	}
	interface SectionName extends KiwiCore.Models.BaseModel {
		SectionNameId: string;
		SectionNameName: string;
		SectionType: KiwiCore.Models.SectionType;
		Publication: KiwiCore.Models.Publication;
		Value: number;
		Text: string;
	}
	interface AdjustmentCode extends KiwiCore.Models.BaseModel {
		AdjustmentCodeId: string;
		Code: string;
		Name: string;
		IsTransfer: boolean;
		Value: number;
		Text: string;
	}
	interface GlAccount extends KiwiCore.Models.BaseModel {
		GlAccountId: string;
		GlAccountCode: string;
		GlAccountDescription: string;
		Value: number;
		Text: string;
	}
	interface Salesperson extends KiwiCore.Models.BaseModel {
		SalespersonId: string;
		SalespersonName: string;
		SalespersonNetName: string;
		SalespersonCode: string;
		SupervisorId: number;
		Value: number;
		Text: string;
	}
	interface AdjustmentReview extends KiwiCore.Models.BaseModel {
		AdjustmentReviewId: number;
		ReviewStatus: KiwiCore.Enums.ReviewStatus;
		ReviewStatusName: string;
		ReviewReason: KiwiCore.Enums.ReviewReason;
		ReviewReasonName: string;
		AdjustmentDetailId: number;
		AssignedUser: KiwiCore.Models.AdvUser;
		ReviewedByUser: KiwiCore.Models.AdvUser;
		RequestedByUser: KiwiCore.Models.AdvUser;
		Notes: string;
		Value: number;
		Text: string;
	}
	interface CategoryName extends KiwiCore.Models.BaseModel {
		CategoryNameId: string;
		CategoryNameName: string;
		SectionType: KiwiCore.Models.SectionType;
		AdTypes: KiwiCore.Models.AdType[];
		SectionNames: KiwiCore.Models.SectionName[];
		Value: number;
		Text: string;
	}
	interface Promotion extends KiwiCore.Models.BaseModel {
		PromoId: string;
		PromoName: string;
		PromoCode: string;
		Value: number;
		Text: string;
	}
	interface Service extends KiwiCore.Models.BaseModel {
		ServiceId: string;
		ServiceName: string;
		Value: number;
		Text: string;
	}
	interface Attachment extends KiwiCore.Models.BaseModel {
		Folder: string;
		AttachmentId: number;
		FileName: string;
		PathName: string;
		TempFileName: string;
		Value: number;
		Text: string;
	}
	interface FiscalPeriod {
		IsCurrentPeriod: boolean;
		PeriodId: number;
		Period: string;
		Year: string;
		PeriodName: string;
		StartDate: Date;
		EndDate: Date;
		StartDateFriendly: string;
		EndDateFriendly: string;
		Value: number;
		Text: string;
	}
	interface SetupIssue extends KiwiCore.Models.BaseModel {
		IssueType: KiwiCore.Enums.IssueType;
		Title: string;
		Description: string;
	}
	interface AdjustmentAcl extends KiwiCore.Models.BaseModel {
		IsUserAuthor: boolean;
		IsMyReviewPending: boolean;
		CanResubmit: boolean;
		CanApproveAcctReview: boolean;
		CanApprovePending: boolean;
		CanApprove: boolean;
	}
	interface ActionableItem {
		ActionType: KiwiCore.Enums.ActionableItem;
		ActionTypeFriendly: string;
		Count: number;
		ActionLink: string;
	}
	interface ListItem {
		Value: string;
		Text: string;
	}
	interface SearchCriteria {
		SearchPhrase: string;
		CreatedOnFrom: Date;
		CreatedOnTo: Date;
		Status: KiwiCore.Models.ListItem[];
		Types: KiwiCore.Models.ListItem[];
		Customers: KiwiCore.Models.ListItem[];
		CreateFiscalPeriods: KiwiCore.Models.ListItem[];
		AdjustmentCodes: KiwiCore.Models.ListItem[];
		Salespersons: KiwiCore.Models.ListItem[];
	}
	interface TaskItem extends KiwiCore.Models.BaseModel {
		CronExpression: string;
		CronExpressionDescription: string;
		IsActive: boolean;
		TaskId: number;
		Site: KiwiCore.Models.Site;
		TaskType: KiwiCore.Enums.TaskType;
		TaskTypeFriendly: string;
		NextRunOn: Date;
		Administrators: KiwiCore.Models.User[];
		SchedulerStartOn: Date;
		SchedulerEndTime: Date;
	}
	interface DummyTaskItem extends KiwiCore.Models.TaskItem {
	}
	interface TaskLogItem extends KiwiCore.Models.BaseModel {
		QueueItem: KiwiCore.Models.TaskQueueItem;
		TaskResult: KiwiCore.Enums.TaskResult;
		TaskResultFriendly: string;
		ResultMsg: string;
	}
	interface TaskQueueItem extends KiwiCore.Models.BaseModel {
		LastResultMsg: string;
		TaskQueueId: number;
		TaskItem: KiwiCore.Models.TaskItem;
		TaskUser: KiwiCore.Models.UserSite;
		TaskQueueStatus: KiwiCore.Enums.TaskQueueStatus;
		TaskQueueStatusFriendly: string;
		RunOn: Date;
		Repo: KiwiCore.IRepository;
	}
	interface DummyTaskQueueItem extends KiwiCore.Models.TaskQueueItem {
	}
	interface AcctReviewUser extends KiwiCore.Models.BaseModel {
		AcctReviewUserId: number;
		AcctReviewUserName: string;
		Value: number;
		Text: string;
	}
	interface ActiveDirectoryCacheItem {
		FirstName: string;
		LastName: string;
		Sid: string;
		Domain: string;
		Email: string;
		NetworkName: string;
		RetrievedOn: Date;
	}
	interface Batch extends KiwiCore.Models.BaseModel {
		BatchId: number;
		Author: KiwiCore.Models.AdvUser;
		Adjustments: KiwiCore.Models.Adjustment[];
		TotalBatchAmount: number;
		Description: string;
		ARAccount: KiwiCore.Models.GlAccount;
		IsCredit: boolean;
		BatchDate: Date;
		Value: number;
		Text: string;
	}
	interface CustomerType extends KiwiCore.Models.BaseModel {
		CustomerTypeId: number;
		CustomerTypeName: string;
		Value: number;
		Text: string;
	}
	interface DashboardItem {
		OrderId: number;
		CreatePeriod: KiwiCore.Models.FiscalPeriod;
		BatchPeriod: KiwiCore.Models.FiscalPeriod;
		AttachmentCount: number;
		CustomerName: string;
		AdjustmentId: number;
		AdjustmentType: KiwiCore.Enums.AdjustmentType;
		AdjustmentTypeFriendly: string;
		DebitAmount: number;
		CreditAmount: number;
		AuthorName: string;
		AuthorNetName: string;
		LastApproverName: string;
		WaitingOnApprovalsFrom: string[];
		WaitingOnApprovalsFromNetNames: string[];
		Description: string;
		CreatedOn: Date;
		CreatedOnFriendly: string;
		InternalNotes: string;
		SiteId: number;
		DelegateFor: string[];
		AdjustmentStatus: KiwiCore.Enums.AdjustmentStatus;
		AdjustmentStatusName: string;
		Details: KiwiCore.Models.AdjustmentDetail[];
		DuplicateCount: number;
		MissingData: string[];
	}
	interface DashboardSummary {
		ReturnedToMe: number;
		PendingMyApproval: number;
		ReadyToBeBatched: number;
		SiteItems: KiwiCore.Models.DashboardSummaryItem[];
		SiteItemsWaitingOnMe: KiwiCore.Models.DashboardItem[];
		MyItemsReturnedToMe: KiwiCore.Models.DashboardItem[];
		MyItems: KiwiCore.Models.DashboardSummaryItem[];
		DelegatorNetNames: string[];
	}
	interface DashboardSummaryItem {
		DebitAmount: number;
		CreditAmount: number;
		AdjustmentStatus: KiwiCore.Enums.AdjustmentStatus;
		AdjustmentStatusName: string;
		Items: KiwiCore.Models.DashboardItem[];
	}
	interface DummyListItem {
		Value: number;
		Text: string;
	}
	interface GLDefault extends KiwiCore.Models.BaseModel {
		GLDefaultId: number;
		GLAccount: KiwiCore.Models.GlAccount;
		Publication: KiwiCore.Models.Publication;
		SectionName: KiwiCore.Models.SectionName;
		SectionType: KiwiCore.Models.SectionType;
		Service: KiwiCore.Models.Service;
		AdType: KiwiCore.Models.AdType;
		CategoryName: KiwiCore.Models.CategoryName;
		Customer: KiwiCore.Models.Customer;
		CustomerType: KiwiCore.Models.CustomerType;
		AdPromotion: KiwiCore.Models.Promotion;
		AdjustmentCode: KiwiCore.Models.AdjustmentCode;
		Value: number;
		Text: string;
	}
	interface IListItem {
		Value: number;
		Text: string;
	}
	interface IListItem<T> {
		Value: T;
		Text: string;
	}
	interface NoneUser extends KiwiCore.Models.User {
	}
	interface NoneUserSite extends KiwiCore.Models.UserSite {
	}
	interface Order extends KiwiCore.Models.BaseModel {
		OrderId: number;
		PoNumber: string;
		Customer: KiwiCore.Models.Customer;
		Value: number;
		Text: string;
	}
	interface ReportData {
		ReportName: string;
		FriendlyReportName: string;
		Path: string;
		Description: string;
		IsFolder: boolean;
		IsHidden: boolean;
		NavigateUrl: string;
		PhxDatabaseName: string;
	}
	interface SysAdminLastSite extends KiwiCore.Models.UserSite {
	}
	interface SettingsModel {
		ClosedForBusiness: boolean;
		Snooze: boolean;
		CreatedOn: Date;
		CreatedBy: string;
		UpdatedOn: Date;
		UpdatedBy: string;
	}
}
declare module System.Collections.Generic {
	interface KeyValuePair<TKey, TValue> {
		Key: TKey;
		Value: TValue;
	}
}
declare module KiwiCore {
	interface IRepository {
		KiwiDb: KiwiCore.IKiwiDb;
	}
	interface IKiwiDb {
	}
}
declare module KiwiCore.Models.Adjustment {
	interface <>c {
		<>9: KiwiCore.Models.Adjustment.<>c;
		<>9__14_0: any;
		<>9__18_0: any;
		<>9__100_0: any;
	}
}
declare module KiwiCore.Models.Batch {
	interface <>c {
		<>9: KiwiCore.Models.Batch.<>c;
		<>9__14_0: any;
		<>9__37_0: any;
	}
}
declare module KiwiCore.Models.DashboardItem {
	interface <>c__DisplayClass97_0 {
		results: string[];
	}
}
declare module KiwiCore.Models.DashboardSummary {
	interface <>c {
		<>9: KiwiCore.Models.DashboardSummary.<>c;
		<>9__8_0: any;
		<>9__8_1: any;
		<>9__14_0: any;
		<>9__17_0: any;
		<>9__17_1: any;
		<>9__26_0: any;
		<>9__26_1: any;
	}
	interface <>c__DisplayClass14_0 {
		dashboardItem: KiwiCore.Models.DashboardItem;
	}
	interface <>c__DisplayClass15_0 {
		netName: string;
	}
	interface <>c__DisplayClass17_0 {
		dashboardItem: KiwiCore.Models.DashboardItem;
	}
}
declare module KiwiCore.Models.DashboardSummaryItem {
	interface <>c {
		<>9: KiwiCore.Models.DashboardSummaryItem.<>c;
		<>9__4_0: any;
		<>9__6_0: any;
	}
}
declare module KiwiCore.Models.Site {
	interface <>c__DisplayClass40_0 {
		role: KiwiCore.Enums.Role;
		<>4__this: KiwiCore.Models.Site;
		<>9__1: any;
	}
	interface <>c {
		<>9: KiwiCore.Models.Site.<>c;
		<>9__40_2: any;
	}
	interface <>c__DisplayClass41_0 {
		includeInactives: boolean;
		role: KiwiCore.Enums.Role;
		<>9__1: any;
	}
}
declare module KiwiCore.Models.UserSite {
	interface <>c__DisplayClass62_0 {
		sb: any;
	}
	interface <>c {
		<>9: KiwiCore.Models.UserSite.<>c;
		<>9__73_0: any;
	}
}
declare module KiwiCore.Enums {
}
